#
# spec file for package libavif
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without aom

# Also update baselibs.conf if you bump the version
%define lib_name libavif13

Name:           libavif
Version:        0.9.3
Release:        150400.1.9
Summary:        Library for encoding and decoding .avif files
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/AOMediaCodec/libavif
#
Source:         https://github.com/AOMediaCodec/libavif/archive/v%{version}/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
#
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libjpeg8-devel
BuildRequires:  nasm
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(rav1e)
BuildRequires:  pkgconfig(zlib)

%if %{with aom}
BuildRequires:  pkgconfig(aom) >= 2.0.0
%endif

%description
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

%package -n avif-tools
Summary:        Tools for libavif
Group:          Productivity/Graphics/Convertors
Provides:       libavif-tools = %{version}
Obsoletes:      libavif-tools < %{version}

%description -n avif-tools
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

This package holds the commandline tools for libavif.

%package -n %{lib_name}
#
Summary:        Shared library from libavif
Group:          Development/Libraries/C and C++

%description -n %{lib_name}
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

This package holds the shared library for libavif.

%package     -n gdk-pixbuf-loader-libavif
Summary:        AVIF image loader for GTK+ applications
Group:          Development/Libraries/C and C++

%description -n gdk-pixbuf-loader-libavif
A pixbuf-loader plugin to load AVIF images in GTK+ applications.

%package devel
Requires:       %{lib_name} = %{version}-%{release}
#
Summary:        Development files for libavif
Group:          Development/Libraries/C and C++

%description devel
This library aims to be a friendly, portable C implementation of the AV1 Image
File Format, as described here:

https://aomediacodec.github.io/av1-avif/

This package holds the development files for libavif.

%prep
%autosetup -p1

%build
%cmake \
 -DAVIF_CODEC_RAV1E:BOOL=ON \
 -DAVIF_CODEC_DAV1D:BOOL=ON \
 %if %{with aom}
 -DAVIF_CODEC_AOM:BOOL=ON \
 %endif
 -DAVIF_BUILD_APPS:BOOL=ON \
 -DAVIF_BUILD_EXAMPLES:BOOL=ON \
 -DAVIF_BUILD_GDK_PIXBUF=ON
%cmake_build

%install
%cmake_install

%post   -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%license LICENSE
%{_libdir}/libavif.so.13
%{_libdir}/libavif.so.13.0.0

%files devel
%license LICENSE
%{_libdir}/libavif.so
%{_includedir}/avif/
%{_libdir}/cmake/libavif/
%{_libdir}/pkgconfig/libavif.pc

%files -n avif-tools
%doc *.md
%license LICENSE
%{_bindir}/avifdec
%{_bindir}/avifenc

%files -n gdk-pixbuf-loader-libavif
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libpixbufloader-avif.so

%changelog
* Thu Oct 21 2021 asn@cryptomilk.org
- Update to version 0.9.3
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.3/CHANGELOG.md
    for a complete changelog.
* Thu Jun 24 2021 asn@cryptomilk.org
- Update to version 0.9.2
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.2/CHANGELOG.md
    for a complete changelog.
* Thu May 20 2021 asn@cryptomilk.org
- Update to version 0.9.1
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.1/CHANGELOG.md
    for a complete changelog.
* Tue Apr 13 2021 dimstar@opensuse.org
- Add baselibs.conf: produce libavif10-32bit as a new dependency to
  libgd3-32bit (support avif in libgd).
* Mon Mar 15 2021 asn@cryptomilk.org
- Update to version 0.9.0
  * See https://github.com/AOMediaCodec/libavif/blob/v0.9.0/CHANGELOG.md
    for a complete changelog.
* Wed Jan 13 2021 bjorn.lie@gmail.com
- Build the gdk-pixbuf module: Add pkgconfig(gdk-pixbuf-2.0)
  BuildRequires and pass DAVIF_BUILD_GDK_PIXBUF=ON to cmake.
  Package the resulting loader in a new sub package.
- Use cmake_build macro.
* Wed Dec  9 2020 asn@cryptomilk.org
- Update to version 0.8.4
  * See https://github.com/AOMediaCodec/libavif/blob/v0.8.4/CHANGELOG.md
    for a complete changelog.
* Thu Oct 15 2020 asn@cryptomilk.org
- Update to version 0.8.2
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
* Mon Aug 17 2020 asn@cryptomilk.org
- Update to version 0.8.1
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
- Enabled AOM support (default)
* Tue Jul 21 2020 asn@cryptomilk.org
- Update to version 0.8.0
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
* Tue May  5 2020 asn@cryptomilk.org
- Update to version 0.7.3
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
  * Removed e4e5d752ece581d6ef9fbb8bab0ab2edfde13fc5.patch
  * Removed ebb29b37711c749681278f8b778f0e6c031c4ca2.patch
  * Removed e7dcc74b5529da209266020852a72b554461e538.patch
* Mon May  4 2020 asn@cryptomilk.org
- Update to version 0.7.2
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
  * Added e4e5d752ece581d6ef9fbb8bab0ab2edfde13fc5.patch
  * Added ebb29b37711c749681278f8b778f0e6c031c4ca2.patch
  * Added e7dcc74b5529da209266020852a72b554461e538.patch
* Thu Apr 23 2020 idonmez@suse.com
- Update to version 0.7.1
  * See https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
    for a complete changelog.
- Add BR on libjpeg8-devel
* Wed Mar 11 2020 asn@cryptomilk.org
- Update to version 0.6.2
  https://github.com/AOMediaCodec/libavif/blob/master/CHANGELOG.md
* Wed Mar 11 2020 asn@cryptomilk.org
- If we want to build with aom, require version >= 1.1.0
- Removed cbcf62c2200be83b85b48059c819ae708216ccec.patch
* Wed Mar  4 2020 asn@cryptomilk.org
- Update to version 0.5.7
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.7
* Sun Feb 16 2020 asn@cryptomilk.org
- Update to version 0.5.5
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.5
- Rename libavif-tools to avif-tools
  This fixes an rpmlint warning
* Wed Dec 11 2019 asn@cryptomilk.org
- Update to version 0.5.3
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.3
* Sun Nov 24 2019 mrueckert@suse.de
- update to 0.5.2
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.2
* Fri Nov 22 2019 mrueckert@suse.de
- update to 0.5.1
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.1
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.5.0
* Wed Nov 20 2019 mrueckert@suse.de
- support building with libaom 1.0.0
  https://github.com/cryptomilk/libavif/commit/cbcf62c2200be83b85b48059c819ae708216ccec.patch
* Wed Nov 20 2019 mrueckert@suse.de
- update to 0.4.8
  https://github.com/AOMediaCodec/libavif/releases/tag/v0.4.8
- drop libs.patch
* Mon Nov 18 2019 mrueckert@suse.de
- initial package
